@@ -5,8 +5,6 @@
  *
  * The library is free for all purposes without any express
  * guarantee it works.
- *
- * Tom St Denis, tomstdenis@gmail.com, http://libtomcrypt.com
  */
 
 /* Implements ECC over Z/pZ for curve y^2 = x^3 - 3x + b
@@ -19,9 +17,9 @@
 /**
   @file ecc_sizes.c
   ECC Crypto, Tom St Denis
-*/  
+*/
 
-#ifdef MECC
+#ifdef LTC_MECC
 
 void ecc_sizes(int *low, int *high)
 {
@@ -42,7 +40,7 @@ void ecc_sizes(int *low, int *high)
 }
 
 #endif
-/* $Source: /cvs/libtom/libtomcrypt/src/pk/ecc/ecc_sizes.c,v $ */
-/* $Revision: 1.4 $ */
-/* $Date: 2006/06/09 01:38:14 $ */
+/* ref:         $Format:%D$ */
+/* git commit:  $Format:%H$ */
+/* commit time: $Format:%ai$ */
 
