@@ -56,6 +56,7 @@
 #include <dirent.h>
 #include <time.h>
 #include <setjmp.h>
+#include <assert.h>
 
 #ifdef HAVE_UTMP_H
 #include <utmp.h>
@@ -203,4 +204,16 @@ extern char** environ;
 # define UNUSED(x) x 
 #endif
 
+/* static_assert() is a keyword in c23, earlier libc often supports
+ * it as a macro in assert.h.
+ * _Static_assert() is a keyword supported since c11.
+ * If neither are available, do nothing */
+#ifndef HAVE_STATIC_ASSERT
+#ifdef HAVE_UNDERSCORE_STATIC_ASSERT
+#define static_assert(condition, message) _Static_assert(condition, message)
+#else
+#define static_assert(condition, message)
+#endif
+#endif
+
 #endif /* DROPBEAR_INCLUDES_H_ */
