@@ -253,6 +253,9 @@ void svr_getopts(int argc, char ** argv) {
 				case 'j':
 					svr_opts.nolocaltcp = 1;
 					break;
+#else
+				case 'j':
+					break;
 #endif
 #if DROPBEAR_SVR_REMOTETCPFWD
 				case 'k':
@@ -261,6 +264,9 @@ void svr_getopts(int argc, char ** argv) {
 				case 'a':
 					opts.listen_fwd_all = 1;
 					break;
+#else
+				case 'k':
+					break;
 #endif
 #if INETD_MODE
 				case 'i':
@@ -289,6 +295,9 @@ void svr_getopts(int argc, char ** argv) {
 				case 'm':
 					svr_opts.domotd = 0;
 					break;
+#else
+				case 'm':
+					break;
 #endif
 				case 'w':
 					svr_opts.norootlogin = 1;
@@ -323,6 +332,10 @@ void svr_getopts(int argc, char ** argv) {
 				case 't':
 					svr_opts.multiauthmethod = 1;
 					break;
+#else
+				case 's':
+				case 'g':
+					break;
 #endif
 				case 'h':
 					printhelp(argv[0]);
@@ -515,6 +528,17 @@ static void disablekey(enum signature_type type) {
 	}
 }
 
+void disable_sig_except(enum signature_type allow_type) {
+	int i;
+	TRACE(("Disabling other sigs except %d", allow_type));
+	for (i = 0; sigalgs[i].name != NULL; i++) {
+		enum signature_type sig_type = sigalgs[i].val;
+		if (sig_type != allow_type) {
+			sigalgs[i].usable = 0;
+		}
+	}
+}
+
 static void loadhostkey_helper(const char *name, void** src, void** dst, int fatal_duplicate) {
 	if (*dst) {
 		if (fatal_duplicate) {
